# myActiveDirectory

The **myActiveDirectory** DSC resources allow you to configure and manage Active Directory Sites and Subnets.

## Description

The **myActiveDirectory** module contains the **myAdSite, myAdSubnet** DSC Resources.
These DSC Resources allow you to configure new AD Sites and AD Subnets.

## Resources

* **myAdSite** creates new Active Directory site.
* **myAdSubnet** creates a new Active Directory Subnet and links it to an AD site.

myAdExchPrepareAD [String] #ResourceName
{
    Arguments = [string]
    Path = [string]
    [Credential = [PSCredential]]
    [DependsOn = [string[]]]
    [PsDscRunAsCredential = [PSCredential]]
}

myAdExchPrepareAllDomains [String] #ResourceName
{
    [Arguments = [string]]
    [Credential = [PSCredential]]
    [DependsOn = [string[]]]
    [Path = [string]]
    [PsDscRunAsCredential = [PSCredential]]
}

myAdExchPrepareSchema [String] #ResourceName
{
    ExchSchemaVersion = [string]
    [Arguments = [string]]
    [Credential = [PSCredential]]
    [DependsOn = [string[]]]
    [Path = [string]]
    [PsDscRunAsCredential = [PSCredential]]
}

### **myAdSite**

myAdSite [String] #ResourceName
{
    Name = [string]
    [Credential = [PSCredential]]
    [DependsOn = [string[]]]
    [Description = [string]]
    [InterSiteTopologyGeneration = [bool]]
    [IntraSiteTopologyGeneration = [bool]]
    [Location = [string]]
    [Protected = [bool]]
    [PsDscRunAsCredential = [PSCredential]]
}

### **myAdSubnet**
myAdSubnet [String] #ResourceName
{
    Name = [string]
    [Credential = [PSCredential]]
    [DependsOn = [string[]]]
    [Description = [string]]
    [Location = [string]]
    [Protected = [bool]]
    [PsDscRunAsCredential = [PSCredential]]
    [Site = [string]]
}

myAdWaitForObject [String] #ResourceName
{
    Identity = [string]
    [Credential = [PSCredential]]
    [DependsOn = [string[]]]
    [PsDscRunAsCredential = [PSCredential]]
    [RetryCount = [UInt32]]
    [RetryIntervalSec = [UInt64]]
    [Server = [string]]
}

## Versions

### 1.1.0.0
* Fixed missing loadmodule ActiveDirectory and add-windowsfeature RSAT-AD-PowerShell if necessary
* Added resources myAdExchPrepareAD, myAdExchPrepareAllDomains, myAdExchPrepareSchema, myAdWaitForObject 

### 1.0.0.0
Initial release with resource my AdSite and myAdSubnet

### **All in one example
$ConfigurationData = @{
	AllNodes = @(@{ NodeName = 'localhost'; PSDscAllowDomainUser = $true; PsDscAllowPlainTextPassword = $true; })
	
	ADSites = @(
	@{
		Name = 'A01'; Description = 'Site A01'; Location = 'Lille'; Protected = $false; Subnets = @(
		@{ Name = '10.10.10.0/24'; Description = 'Room 01'; Location = 'Building East'; Protected = $false; },
		@{ Name = '10.10.11.0/24'; Description = 'Room 02'; Location = 'Building East'; Protected = $false; },
		@{ Name = '10.10.12.0/24'; Description = 'Room 03'; Location = 'Building North'; Protected = $false; }
		)
	},
	@{
		Name = 'A02'; Description = 'Site A02'; Location = 'Brussels'; Protected = $false; Subnets = @(
		@{ Name = '10.10.13.0/24'; Description = 'Room 04'; Location = 'Building South'; Protected = $false; },
		@{ Name = '10.10.14.0/24'; Description = 'Room 05'; Location = 'Building West'; Protected = $false; }
		)
	},
	@{
		Name = 'A03'; Description = 'Site A03'; Location = 'London'; Protected = $false; Subnets = @(
		@{ Name = '10.10.15.0/24'; Description = 'Room 06'; Location = 'Building West'; Protected = $false; }
		)
	}
	) #$ADSites
} #$ConfigurationData


Configuration myActiveDirectory01
{
	param
	(
		[Parameter(Mandatory)]
		[PSCredential]$DomainAdminCreds
	)
	Import-DscResource -ModuleName myActiveDirectory
	
	$ADSites = $ConfigurationData.ADSites
	
	node localhost
	{
		foreach ($ADSite in $ADSites)
		{
			Write-Verbose "Site: $($ADSite.Name) $($ADSite.Description) $($ADSite.Location) $($ADSite.Protected)"
			myAdSite "AdSite-$($ADSite.Name)"
			{
				Name = $ADSite.Name
				Location = $ADSite.Location
				Description = $ADSite.Description
				Protected = $ADSite.Protected
				DomainAdminCreds = $DomainAdminCreds
			}
			
			foreach ($Subnet in $ADSite.Subnets)
			{
				Write-Verbose "   Subnet: $($Subnet.Name) $($Subnet.Description) $($Subnet.Location) $($Subnet.Protected)"
				myAdSubnet "AdSubnet-$($Subnet.Name)"
				{
					Name = $Subnet.Name
					Site = $ADSite.Name
					Location = $Subnet.Location
					Description = $Subnet.Description
					Protected = $Subnet.Protected
					DomainAdminCreds = $DomainAdminCreds
				}
			} #foreach ($Subnet in $ADSite.Subnets)
		} #foreach ($ADSite in $ADSites)
	} #node localhost
} #Configuration Test01

if ($DomainAdminCreds -eq $null) { $DomainAdminCreds = Get-Credential -UserName 'DSCDOMAIN\administrator' -Message 'Domain Admin Credentials' }

myActiveDirectory01 -ConfigurationData $ConfigurationData -Verbose -OutputPath 'C:\DSC\myActiveDirectory01' -DomainAdminCreds $DomainAdminCreds
Start-DscConfiguration -Wait -Force -Verbose -Path 'C:\DSC\myActiveDirectory01'






